pub struct ProvideDocumentRangeFormattingRequest {
pub uri: Option<Uri>,
pub range: Option<Range>,
pub tab_size: u32,
pub insert_spaces: bool,
pub provider_handle: u32,
}Expand description
Request for range formatting.
Fields
uri: Option<Uri>range: Option<Range>tab_size: u32insert_spaces: boolprovider_handle: u32Trait Implementations
Sourceimpl Clone for ProvideDocumentRangeFormattingRequest
impl Clone for ProvideDocumentRangeFormattingRequest
Sourcefn clone(&self) -> ProvideDocumentRangeFormattingRequest
fn clone(&self) -> ProvideDocumentRangeFormattingRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Message for ProvideDocumentRangeFormattingRequest
impl Message for ProvideDocumentRangeFormattingRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ProvideDocumentRangeFormattingRequest
impl PartialEq for ProvideDocumentRangeFormattingRequest
Sourcefn eq(&self, other: &ProvideDocumentRangeFormattingRequest) -> bool
fn eq(&self, other: &ProvideDocumentRangeFormattingRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for ProvideDocumentRangeFormattingRequest
impl StructuralPartialEq for ProvideDocumentRangeFormattingRequest