pub struct RegisterSignatureHelpProviderRequest {
pub language_selector: String,
pub handle: u32,
pub extension_id: String,
pub trigger_characters: Vec<String>,
pub retrigger_characters: Vec<String>,
}Expand description
Request to register signature help provider with metadata.
Fields
language_selector: Stringhandle: u32extension_id: Stringtrigger_characters: Vec<String>retrigger_characters: Vec<String>Trait Implementations
Sourceimpl Clone for RegisterSignatureHelpProviderRequest
impl Clone for RegisterSignatureHelpProviderRequest
Sourcefn clone(&self) -> RegisterSignatureHelpProviderRequest
fn clone(&self) -> RegisterSignatureHelpProviderRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Message for RegisterSignatureHelpProviderRequest
impl Message for RegisterSignatureHelpProviderRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for RegisterSignatureHelpProviderRequest
impl PartialEq for RegisterSignatureHelpProviderRequest
Sourcefn eq(&self, other: &RegisterSignatureHelpProviderRequest) -> bool
fn eq(&self, other: &RegisterSignatureHelpProviderRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for RegisterSignatureHelpProviderRequest
impl StructuralPartialEq for RegisterSignatureHelpProviderRequest